<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pl">
<context>
    <name>AccountItem</name>
    <message>
        <source>Sync successful</source>
        <translation type="vanished">Synchronizacja zakończona</translation>
    </message>
    <message>
        <source>Network error</source>
        <translation type="vanished">Błąd sieci</translation>
    </message>
    <message>
        <source>Server exception</source>
        <translation type="vanished">Wyjątek serwera</translation>
    </message>
    <message>
        <source>Storage full</source>
        <translation type="vanished">Pamięć pełna</translation>
    </message>
</context>
<context>
    <name>AccountManager</name>
    <message>
        <source>Local account</source>
        <translation type="vanished">Konto lokalne</translation>
    </message>
    <message>
        <source>Event types</source>
        <translation type="vanished">Typy wydarzeń</translation>
    </message>
</context>
<context>
    <name>CColorPickerWidget</name>
    <message>
        <source>Color</source>
        <translation type="vanished">Kolor</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation type="vanished">Anuluj</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation type="vanished">Zapisz</translation>
    </message>
</context>
<context>
    <name>CDayMonthView</name>
    <message>
        <source>Monday</source>
        <translation type="vanished">Poniedziałek</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation type="vanished">Wtorek</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation type="vanished">Środa</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation type="vanished">Czwartek</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation type="vanished">Piątek</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation type="vanished">Sobota</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation type="vanished">Niedziela</translation>
    </message>
</context>
<context>
    <name>CDayWindow</name>
    <message>
        <source>Y</source>
        <translation type="vanished">R</translation>
    </message>
    <message>
        <source>M</source>
        <translation type="vanished">M</translation>
    </message>
    <message>
        <source>D</source>
        <translation type="vanished">D</translation>
    </message>
    <message>
        <source>Lunar</source>
        <translation type="vanished">Księżycowy</translation>
    </message>
</context>
<context>
    <name>CGraphicsView</name>
    <message>
        <source>New Event</source>
        <translation type="vanished">Nowe wydarzenie</translation>
    </message>
</context>
<context>
    <name>CMonthScheduleNumItem</name>
    <message>
        <source>%1 more</source>
        <translation type="vanished">jeszcze 1%</translation>
    </message>
</context>
<context>
    <name>CMonthView</name>
    <message>
        <source>New event</source>
        <translation type="vanished">Nowe wydarzenie</translation>
    </message>
    <message>
        <source>New Event</source>
        <translation type="vanished">Nowe wydarzenie</translation>
    </message>
</context>
<context>
    <name>CMonthWindow</name>
    <message>
        <source>Y</source>
        <translation type="vanished">R</translation>
    </message>
</context>
<context>
    <name>CMyScheduleView</name>
    <message>
        <source>My Event</source>
        <translation type="vanished">Moje wydarzenie</translation>
    </message>
    <message>
        <source>OK</source>
        <comment>button</comment>
        <translation type="vanished">OK</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation type="vanished">Usuń</translation>
    </message>
    <message>
        <source>Edit</source>
        <comment>button</comment>
        <translation type="vanished">Edytuj</translation>
    </message>
</context>
<context>
    <name>CPushButton</name>
    <message>
        <source>New event type</source>
        <translation type="vanished">Nowy typ wydarzenia</translation>
    </message>
</context>
<context>
    <name>CScheduleDlg</name>
    <message>
        <source>New Event</source>
        <translation type="vanished">Nowe wydarzenie</translation>
    </message>
    <message>
        <source>Edit Event</source>
        <translation type="vanished">Edytuj wydarzenie</translation>
    </message>
    <message>
        <source>End time must be greater than start time</source>
        <translation type="vanished">Czas zakończenia musi być późniejszy niż czas rozpoczęcia</translation>
    </message>
    <message>
        <source>OK</source>
        <comment>button</comment>
        <translation type="vanished">OK</translation>
    </message>
    <message>
        <source>Never</source>
        <translation type="vanished">Nigdy</translation>
    </message>
    <message>
        <source>At time of event</source>
        <translation type="vanished">W czasie wydarzenia</translation>
    </message>
    <message>
        <source>15 minutes before</source>
        <translation type="vanished">15 minut przed</translation>
    </message>
    <message>
        <source>30 minutes before</source>
        <translation type="vanished">30 minut przed</translation>
    </message>
    <message>
        <source>1 hour before</source>
        <translation type="vanished">1 godzinę przed</translation>
    </message>
    <message>
        <source>1 day before</source>
        <translation type="vanished">1 dzień przed</translation>
    </message>
    <message>
        <source>2 days before</source>
        <translation type="vanished">2 dni przed</translation>
    </message>
    <message>
        <source>1 week before</source>
        <translation type="vanished">1 tydzień przed</translation>
    </message>
    <message>
        <source>On start day (9:00 AM)</source>
        <translation type="vanished">W dniu rozpoczęcia (9:00)</translation>
    </message>
    <message>
        <source>time(s)</source>
        <translation type="vanished">raz(y)</translation>
    </message>
    <message>
        <source>Enter a name please</source>
        <translation type="vanished">Wprowadź nazwę</translation>
    </message>
    <message>
        <source>The name can not only contain whitespaces</source>
        <translation type="vanished">Nazwa nie może zawierać tylko białych znaków</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation type="vanished">Typ:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation type="vanished">Opis:</translation>
    </message>
    <message>
        <source>All Day:</source>
        <translation type="vanished">Cały dzień:</translation>
    </message>
    <message>
        <source>Starts:</source>
        <translation type="vanished">Początek:</translation>
    </message>
    <message>
        <source>Ends:</source>
        <translation type="vanished">Koniec:</translation>
    </message>
    <message>
        <source>Remind Me:</source>
        <translation type="vanished">Przypomnij mi:</translation>
    </message>
    <message>
        <source>Repeat:</source>
        <translation type="vanished">Powtórz:</translation>
    </message>
    <message>
        <source>End Repeat:</source>
        <translation type="vanished">Zakończ powtarzanie:</translation>
    </message>
    <message>
        <source>Calendar account:</source>
        <translation type="vanished">Konto kalendarza:</translation>
    </message>
    <message>
        <source>Calendar account</source>
        <translation type="vanished">Konto kalendarza</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="vanished">Typ</translation>
    </message>
    <message>
        <source>Description</source>
        <translation type="vanished">Opis</translation>
    </message>
    <message>
        <source>All Day</source>
        <translation type="vanished">Cały dzień</translation>
    </message>
    <message>
        <source>Time:</source>
        <translation type="vanished">Czas:</translation>
    </message>
    <message>
        <source>Time</source>
        <translation type="vanished">Czas</translation>
    </message>
    <message>
        <source>Solar</source>
        <translation type="vanished">Słoneczny</translation>
    </message>
    <message>
        <source>Lunar</source>
        <translation type="vanished">Księżycowy</translation>
    </message>
    <message>
        <source>Starts</source>
        <translation type="vanished">Początek</translation>
    </message>
    <message>
        <source>Ends</source>
        <translation type="vanished">Koniec</translation>
    </message>
    <message>
        <source>Remind Me</source>
        <translation type="vanished">Przypomnij mi</translation>
    </message>
    <message>
        <source>Repeat</source>
        <translation type="vanished">Powtórz</translation>
    </message>
    <message>
        <source>Daily</source>
        <translation type="vanished">Codziennie</translation>
    </message>
    <message>
        <source>Weekdays</source>
        <translation type="vanished">W dni robocze</translation>
    </message>
    <message>
        <source>Weekly</source>
        <translation type="vanished">Co tydzień</translation>
    </message>
    <message>
        <source>Monthly</source>
        <translation type="vanished">Co miesiąc</translation>
    </message>
    <message>
        <source>Yearly</source>
        <translation type="vanished">Co rok</translation>
    </message>
    <message>
        <source>End Repeat</source>
        <translation type="vanished">Zakończ Powtarzanie</translation>
    </message>
    <message>
        <source>After</source>
        <translation type="vanished">Po</translation>
    </message>
    <message>
        <source>On</source>
        <translation type="vanished">Wł</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation type="vanished">Anuluj</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation type="vanished">Zapisz</translation>
    </message>
</context>
<context>
    <name>CScheduleOperation</name>
    <message>
        <source>All occurrences of a repeating event must have the same all-day status.</source>
        <translation type="vanished">Wszystkie wystąpienia powtarzającego się wydarzenia muszą zawierać ten sam stan całodniowy.</translation>
    </message>
    <message>
        <source>Do you want to change all occurrences?</source>
        <translation type="vanished">Czy chcesz zmienić wszystkie wystąpienia?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation type="vanished">Anuluj</translation>
    </message>
    <message>
        <source>Change All</source>
        <translation type="vanished">Zmień wszystkie</translation>
    </message>
    <message>
        <source>You are changing the repeating rule of this event.</source>
        <translation type="vanished">Zmieniasz regułę powtarzania tego wydarzenia.</translation>
    </message>
    <message>
        <source>You are deleting an event.</source>
        <translation type="vanished">Usuwasz wydarzenie.</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this event?</source>
        <translation type="vanished">Czy na pewno chcesz usunąć to wydarzenie?</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation type="vanished">Usuń</translation>
    </message>
    <message>
        <source>Do you want to delete all occurrences of this event, or only the selected occurrence?</source>
        <translation type="vanished">Czy chcesz usunąć wszystkie wystąpienia tego zdarzenia, czy tylko wybrane wystąpienie?</translation>
    </message>
    <message>
        <source>Delete All</source>
        <translation type="vanished">Usuń wszystkie</translation>
    </message>
    <message>
        <source>Delete Only This Event</source>
        <translation type="vanished">Usuń tylko to wydarzenie</translation>
    </message>
    <message>
        <source>Do you want to delete this and all future occurrences of this event, or only the selected occurrence?</source>
        <translation type="vanished">Czy chcesz usunąć to i wszystkie przyszłe wystąpienia tego wydarzenia, czy tylko wybrane wystąpienie?</translation>
    </message>
    <message>
        <source>Delete All Future Events</source>
        <translation type="vanished">Usuń wszystkie przyszłe wydarzenia</translation>
    </message>
    <message>
        <source>You are changing a repeating event.</source>
        <translation type="vanished">Zmieniasz powtarzające się wydarzenie.</translation>
    </message>
    <message>
        <source>Do you want to change only this occurrence of the event, or all occurrences?</source>
        <translation type="vanished">Czy chcesz zmienić tylko to wystąpienie wydarzenia, czy wszystkie wydarzenia?</translation>
    </message>
    <message>
        <source>All</source>
        <translation type="vanished">Wszystko</translation>
    </message>
    <message>
        <source>Only This Event</source>
        <translation type="vanished">Tylko to wydarzenie</translation>
    </message>
    <message>
        <source>Do you want to change only this occurrence of the event, or this and all future occurrences?</source>
        <translation type="vanished">Czy chcesz zmienić tylko to wystąpienie wydarzenia, czy to i wszystkie przyszłe wydarzenia?</translation>
    </message>
    <message>
        <source>All Future Events</source>
        <translation type="vanished">Wszystkie przyszłe wydarzenia</translation>
    </message>
    <message>
        <source>You have selected a leap month, and will be reminded according to the rules of the lunar calendar.</source>
        <translation type="vanished">Zaznaczono miesiąc przestępny, przypomnienie będzie działać zgodnie z zasadami kalendarza księżycowego.</translation>
    </message>
    <message>
        <source>OK</source>
        <comment>button</comment>
        <translation type="vanished">OK</translation>
    </message>
</context>
<context>
    <name>CScheduleSearchDateItem</name>
    <message>
        <source>Y</source>
        <translation type="vanished">R</translation>
    </message>
    <message>
        <source>M</source>
        <translation type="vanished">M</translation>
    </message>
    <message>
        <source>D</source>
        <translation type="vanished">D</translation>
    </message>
</context>
<context>
    <name>CScheduleSearchItem</name>
    <message>
        <source>Edit</source>
        <translation type="vanished">Edytuj</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="vanished">Usuń</translation>
    </message>
    <message>
        <source>All Day</source>
        <translation type="vanished">Cały dzień</translation>
    </message>
</context>
<context>
    <name>CScheduleSearchView</name>
    <message>
        <source>No search results</source>
        <translation type="vanished">Brak wyników wyszukiwania</translation>
    </message>
</context>
<context>
    <name>CScheduleView</name>
    <message>
        <source>ALL DAY</source>
        <translation type="vanished">CAŁY DZIEŃ</translation>
    </message>
</context>
<context>
    <name>CSettingDialog</name>
    <message>
        <source>Manual</source>
        <translation type="vanished">Ręcznie</translation>
    </message>
    <message>
        <source>15 mins</source>
        <translation type="vanished">15 min</translation>
    </message>
    <message>
        <source>30 mins</source>
        <translation type="vanished">30 min</translation>
    </message>
    <message>
        <source>1 hour</source>
        <translation type="vanished">1 godz</translation>
    </message>
    <message>
        <source>24 hours</source>
        <translation type="vanished">24 godz</translation>
    </message>
    <message>
        <source>Sync Now</source>
        <translation type="vanished">Synchronizuj teraz</translation>
    </message>
    <message>
        <source>Last sync</source>
        <translation type="vanished">Ostatnia synchronizacja</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation type="vanished">Poniedziałek</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation type="vanished">Niedziela</translation>
    </message>
    <message>
        <source>12-hour clock</source>
        <translation type="vanished">Zegar 12-godzinny</translation>
    </message>
    <message>
        <source>24-hour clock</source>
        <translation type="vanished">Zegar 24-godzinny</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wednesday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Thursday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Friday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Saturday</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>CTimeEdit</name>
    <message>
        <source>(%1 mins)</source>
        <translation type="vanished">(%1 minut)</translation>
    </message>
    <message>
        <source>(%1 hour)</source>
        <translation type="vanished">(%1 godzina)</translation>
    </message>
    <message>
        <source>(%1 hours)</source>
        <translation type="vanished">(%1 godzin)</translation>
    </message>
</context>
<context>
    <name>CTitleWidget</name>
    <message>
        <source>Y</source>
        <translation type="vanished">R</translation>
    </message>
    <message>
        <source>M</source>
        <translation type="vanished">M</translation>
    </message>
    <message>
        <source>W</source>
        <translation type="vanished">T</translation>
    </message>
    <message>
        <source>D</source>
        <translation type="vanished">D</translation>
    </message>
    <message>
        <source>Search events and festivals</source>
        <translation type="vanished">Szukaj wydarzeń i festiwalów</translation>
    </message>
</context>
<context>
    <name>CWeekWidget</name>
    <message>
        <source>Sun</source>
        <translation type="vanished">Nie</translation>
    </message>
    <message>
        <source>Mon</source>
        <translation type="vanished">Pon</translation>
    </message>
    <message>
        <source>Tue</source>
        <translation type="vanished">Wt</translation>
    </message>
    <message>
        <source>Wed</source>
        <translation type="vanished">Śr</translation>
    </message>
    <message>
        <source>Thu</source>
        <translation type="vanished">Czw</translation>
    </message>
    <message>
        <source>Fri</source>
        <translation type="vanished">Pt</translation>
    </message>
    <message>
        <source>Sat</source>
        <translation type="vanished">Sob</translation>
    </message>
</context>
<context>
    <name>CWeekWindow</name>
    <message>
        <source>Week</source>
        <translation type="vanished">Tydzień</translation>
    </message>
    <message>
        <source>Y</source>
        <translation type="vanished">R</translation>
    </message>
</context>
<context>
    <name>CYearScheduleView</name>
    <message>
        <source>All Day</source>
        <translation type="vanished">Cały dzień</translation>
    </message>
    <message>
        <source>No event</source>
        <translation type="vanished">Brak wydarzeń</translation>
    </message>
</context>
<context>
    <name>CYearWindow</name>
    <message>
        <source>Y</source>
        <translation type="vanished">R</translation>
    </message>
</context>
<context>
    <name>CalendarWindow</name>
    <message>
        <source>Calendar</source>
        <translation type="vanished">Kalendarz</translation>
    </message>
    <message>
        <source>Calendar is a tool to view dates, and also a smart daily planner to schedule all things in life. </source>
        <translation type="vanished">Kalendarz to narzędzie umożliwiające przeglądanie dat, jak i inteligentny terminarz, w którym możesz zaplanować wszystkie wydarzenia w życiu.</translation>
    </message>
</context>
<context>
    <name>Calendarmainwindow</name>
    <message>
        <source>Calendar</source>
        <translation type="vanished">Kalendarz</translation>
    </message>
    <message>
        <source>Manage</source>
        <translation type="vanished">Zarządzaj</translation>
    </message>
    <message>
        <source>Privacy Policy</source>
        <translation type="vanished">Polityka prywatności</translation>
    </message>
    <message>
        <source>Syncing...</source>
        <translation type="vanished">Synchronizuję...</translation>
    </message>
    <message>
        <source>Sync successful</source>
        <translation type="vanished">Synchronizacja zakończona</translation>
    </message>
    <message>
        <source>Sync failed, please try later</source>
        <translation type="vanished">Błąd synchronizacji, spróbuj ponownie później</translation>
    </message>
</context>
<context>
    <name>CenterWidget</name>
    <message>
        <source>All Day</source>
        <translation type="vanished">Cały dzień</translation>
    </message>
</context>
<context>
    <name>DAccountDataBase</name>
    <message>
        <source>Work</source>
        <translation>Praca</translation>
    </message>
    <message>
        <source>Life</source>
        <translation>Życie</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Inne</translation>
    </message>
</context>
<context>
    <name>DAlarmManager</name>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation>Zamknij</translation>
    </message>
    <message>
        <source>One day before start</source>
        <translation>Dzień przed rozpoczęciem</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation>Przypomnij mi jutro</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Przypomnij mi później</translation>
    </message>
    <message>
        <source>15 mins later</source>
        <translation>15 minut później</translation>
    </message>
    <message>
        <source>1 hour later</source>
        <translation>1 godzinę później</translation>
    </message>
    <message>
        <source>4 hours later</source>
        <translation>4 godziny później</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation>Jutro</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation>Zaplanuj przypomnienie</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation>%1 do %2</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Dzisiaj</translation>
    </message>
</context>
<context>
    <name>DragInfoGraphicsView</name>
    <message>
        <source>Edit</source>
        <translation type="vanished">Edytuj</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="vanished">Usuń</translation>
    </message>
    <message>
        <source>New event</source>
        <translation type="vanished">Nowe wydarzenie</translation>
    </message>
    <message>
        <source>New Event</source>
        <translation type="vanished">Nowe wydarzenie</translation>
    </message>
</context>
<context>
    <name>JobTypeListView</name>
    <message>
        <source>You are deleting an event type.</source>
        <translation type="vanished">Usuwasz typ wydarzenia.</translation>
    </message>
    <message>
        <source>All events under this type will be deleted and cannot be recovered.</source>
        <translation type="vanished">Wszystkie wydarzenia skatalogowane pod tym typem zostaną usunięte i nie będzie można ich przywrócić.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation type="vanished">Anuluj</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation type="vanished">Usuń</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Account settings</source>
        <translation type="vanished">Ustawienia konta</translation>
    </message>
    <message>
        <source>Account</source>
        <translation type="vanished">Konto</translation>
    </message>
    <message>
        <source>Select items to be synced</source>
        <translation type="vanished">Wybierz przedmioty do synchronizacji</translation>
    </message>
    <message>
        <source>Events</source>
        <translation type="vanished">Wydarzenia</translation>
    </message>
    <message>
        <source>General settings</source>
        <translation type="vanished">Ustawienia ogólne</translation>
    </message>
    <message>
        <source>Sync interval</source>
        <translation type="vanished">Interwał synchronizacji</translation>
    </message>
    <message>
        <source>Manage calendar</source>
        <translation type="vanished">Zarządzaj kalendarzem</translation>
    </message>
    <message>
        <source>Calendar account</source>
        <translation type="vanished">Konto kalendarza</translation>
    </message>
    <message>
        <source>Event types</source>
        <translation type="vanished">Typy wydarzeń</translation>
    </message>
    <message>
        <source>General</source>
        <translation type="vanished">Ogólne</translation>
    </message>
    <message>
        <source>First day of week</source>
        <translation type="vanished">Pierwszy dzień tygodnia</translation>
    </message>
    <message>
        <source>Time</source>
        <translation type="vanished">Czas</translation>
    </message>
</context>
<context>
    <name>Return</name>
    <message>
        <source>Today</source>
        <comment>Return</comment>
        <translation type="vanished">Dzisiaj</translation>
    </message>
</context>
<context>
    <name>Return Today</name>
    <message>
        <source>Today</source>
        <comment>Return Today</comment>
        <translation type="vanished">Dzisiaj</translation>
    </message>
</context>
<context>
    <name>ScheduleTypeEditDlg</name>
    <message>
        <source>New event type</source>
        <translation type="vanished">Nowy typ wydarzenia</translation>
    </message>
    <message>
        <source>Edit event type</source>
        <translation type="vanished">Edytuj typ wydarzenia</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation type="vanished">Nazwa:</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation type="vanished">Kolor:</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation type="vanished">Anuluj</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation type="vanished">Zapisz</translation>
    </message>
    <message>
        <source>The name can not only contain whitespaces</source>
        <translation type="vanished">Nazwa nie może zawierać tylko znaków spacji</translation>
    </message>
    <message>
        <source>Enter a name please</source>
        <translation type="vanished">Wprowadź nazwę</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation type="vanished">Pomoc</translation>
    </message>
    <message>
        <source>Delete event</source>
        <translation type="vanished">Usuń wydarzenie</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="vanished">Kopiuj</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation type="vanished">Wytnij</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation type="vanished">Wklej</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="vanished">Usuń</translation>
    </message>
    <message>
        <source>Select all</source>
        <translation type="vanished">Zaznacz wszystko</translation>
    </message>
</context>
<context>
    <name>SidebarCalendarWidget</name>
    <message>
        <source>Y</source>
        <translation type="vanished">R</translation>
    </message>
    <message>
        <source>M</source>
        <translation type="vanished">M</translation>
    </message>
</context>
<context>
    <name>TimeJumpDialog</name>
    <message>
        <source>Go</source>
        <comment>button</comment>
        <translation type="vanished">Przejdź</translation>
    </message>
</context>
<context>
    <name>UserloginWidget</name>
    <message>
        <source>Sign In</source>
        <comment>button</comment>
        <translation type="vanished">Zaloguj się</translation>
    </message>
    <message>
        <source>Sign Out</source>
        <comment>button</comment>
        <translation type="vanished">Wyloguj się</translation>
    </message>
</context>
<context>
    <name>YearFrame</name>
    <message>
        <source>Y</source>
        <translation type="vanished">R</translation>
    </message>
</context>
<context>
    <name>today</name>
    <message>
        <source>Today</source>
        <comment>Today</comment>
        <translation type="vanished">Dzisiaj</translation>
    </message>
</context>
</TS>